; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below.
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;

[Command]
name = "NyahNyahBlow"
command = ~D, F, D, F, x+y
time = 40

[Command]
name = "APurrfectCombination"
command = ~D, F, D, B, x
time = 30

[Command]
name = "APurrfectCombination"   ;Same name as above
command = ~D, F, D, B, y
time = 30


;-| Special Motions |------------------------------------------------------
[Command]
name = "FDF_x"
command = ~F, D, DF, F, x

[Command]
name = "FDF_y"
command = ~F, D, DF, F, y

[Command]
name = "QCF_xy"
command = ~D, F, x+y

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCB_xy"
command = ~D, B, x+y

[Command]
name = "QCB_x"
command = ~D, B, x

[Command]
name = "QCB_y"
command = ~D, B, y

[Command]
name = "QCF_ab"
command = ~D, F, a+b

[Command]
name = "QCF_a"
command = ~D, F, a

[Command]
name = "QCF_b"
command = ~D, F, b

[Command]
name = "QCB_ab"
command = ~D, B, a+b

[Command]
name = "QCB_a"
command = ~D, B, a

[Command]
name = "QCB_b"
command = ~D, B, b

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = z
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "xy"
command = x+y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1
;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(1) = 0

[State -1, Combo condition Check]
type = VarSet
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact
var(1) = 1

;---------------------------------------------------------------------------
;Nyah Nyah Blow (Hyper)
[State -1, Moe Moe Kyun! (Hyper)]
type = ChangeState
value = 3050
triggerall = command = "NyahNyahBlow"
triggerall = power >= 3000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = 200 || stateno = 210 || stateno = 215 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440)
trigger2 = movecontact

;---------------------------------------------------------------------------
;A Purrfect Combination (Hyper)
[State -1, A Purrfect Combination (Hyper)]
type = ChangeState
value = 3000
triggerall = command = "APurrfectCombination"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = 200 || stateno = 210 || stateno = 215 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) 
trigger2 = movecontact

;---------------------------------------------------------------------------
;Cat Mode Change
[State -1, Cat Mode Change]
type = ChangeState
value = 1
triggerall = command = "xy"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Cat Kick (Light)
[State -1, Cat Kick (Light)]
type = ChangeState
value = 1130
triggerall = command = "QCB_a"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = 200 || stateno = 210 || stateno = 215 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Cat Kick (Strong)
[State -1, Cat Kick (Strong)]
type = ChangeState
value = 1140
triggerall = command = "QCB_b"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = 200 || stateno = 210 || stateno = 215 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440)

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Throw
[State -1, Throw]
type = ChangeState
value = 800
triggerall = command = "y"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200 
trigger2 = time > 12

;---------------------------------------------------------------------------
;Standing Pounce Attack
[State -1, Standing Pounce Attack]
type = ChangeState
value = 215
triggerall = command = "y"
triggerall = command = "holdfwd"
triggerall = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 205 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 205 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = command = "a"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 230
trigger2 = time > 20

;---------------------------------------------------------------------------
;Standing Rump Shaker
[State -1, Standing Rump Shaker]
type = ChangeState
value = 240
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 205 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 400
trigger2 = time > 15

;---------------------------------------------------------------------------
;Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno  = 205 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 430 
trigger2 = time > 15

;---------------------------------------------------------------------------
;Crouching Senton
[State -1, Crouching Senton]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 205 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = time > 12

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 || stateno = 630) && movecontact

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl 
trigger2 = stateno = 630
trigger2 = time > 30

;---------------------------------------------------------------------------
;Jump Drop Kick
[State -1, Jump Drop Kick]
type = ChangeState
value = 640
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 || stateno = 630) && movecontact

;---------------------------------------------------------------------------
; Dizzy Cancel (Stand) (Normal)
[State -1, |Dizzy Cancel Stand|]
type = ChangeState
value = 6060+(statetype = S)
triggerall =  movetype != H
triggerall = statetype != C
triggerall = var(3) < 3
triggerall = command = "c" && power > 500
trigger1 = (stateno = 600 || stateno = 610) || (stateno = [630,640])
trigger1 = movehit
trigger2 = (stateno = 200 || stateno = 210 || stateno = 216 || stateno = 230 || stateno = 240) || (stateno = [400,499])
trigger2 = movehit
trigger3 = (stateno = [1130,1134]) || (stateno = [1140,1144])
trigger3 = movehit

;---------------------------------------------------------------------------
; Dizzy Cancel (Crouch) (Normal)
[State -1, |Dizzy Cancel Crouch|]
type = ChangeState
value = 6062
triggerall =  movetype != H
triggerall = statetype = C
triggerall = var(3) < 3
triggerall = command = "c" && power > 500
trigger1 = (stateno = 600 || stateno = 610) || (stateno = [630,640])
trigger1 = movehit
trigger2 = (stateno = 200 || stateno = 210 || stateno = 216 || stateno = 230 || stateno = 240) || (stateno = [400,499])
trigger2 = movehit
trigger3 = (stateno = [1031,1033]) || (stateno = [1041,1043])
trigger3 = movehit
trigger4 = (stateno = [1130,1134]) || (stateno = [1140,1144])
trigger4 = movehit

;---------------------------------------------------------------------------
; Dizzy Cancel (Stand) (Cat Mode)
[State -1, |Dizzy Cancel Stand|]
type = ChangeState
value = 6065+(statetype = S)
triggerall =  movetype != H
triggerall = statetype != C
triggerall = var(3) < 3
triggerall = command = "c" && power > 500
trigger1 = (stateno = 601 || stateno = 611)
trigger1 = movehit
trigger2 = (stateno = [1000,1019])
trigger2 = movehit
trigger3 = (stateno = [1030,1032]) || (stateno = [1040,1042])
trigger3 = movehit
trigger4 = numhelper(1061)
trigger4 = helper(1061),movehit
trigger5 = numhelper(1071)
trigger5 = helper(1071),movehit
trigger6 =  (stateno = [1135,1139]) || (stateno = [1145,1149])
trigger6 = movehit
trigger7 = (stateno = [1200,1219])
trigger7 = movehit

;---------------------------------------------------------------------------
; Dizzy Cancel (Crouch) (Cat Mode)
[State -1, |Dizzy Cancel Crouch|]
type = ChangeState
value = 6067
triggerall =  movetype != H
triggerall = statetype = C
triggerall = var(3) < 3
triggerall = command = "c" && power > 500
trigger1 = (stateno = 201 || stateno = 211)
trigger1 = movehit
trigger2 = (stateno = [1000,1019])
trigger2 = movehit
trigger3 = numhelper(1061)
trigger3 = helper(1061),movehit
trigger4 = numhelper(1071)
trigger4 = helper(1071),movehit
trigger5 = (stateno = [1100,1119])
trigger5 = movehit

;---------------------------------------------------------------------------
; Dizzy Guard Cancel (Air)
[State -1, |Dizzy Guard Cancel Air|]
type = ChangeState
value = 6070
triggerall =  movetype = H
triggerall = statetype = A
triggerall = command = "z" && power > 1000
trigger1 = stateno = 154

;---------------------------------------------------------------------------
; Dizzy Guard Cancel (Stand)
[State -1, |Dizzy Guard Cancel Stand|]
type = ChangeState
value = 6071
triggerall =  movetype = H
triggerall = statetype = S
triggerall = command = "z" && power > 1000
trigger1 = stateno = 150

;---------------------------------------------------------------------------
; Dizzy Guard Cancel (Crouch)
[State -1, |Dizzy Guard Cancel Crouch|]
type = ChangeState
value = 6072
triggerall =  movetype = H
triggerall = statetype = C
triggerall = command = "z" && power > 1000
trigger1 = stateno = 152

;---------------------------------------------------------------------------